"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexAccessNode = void 0;
const Node_cjs_1 = require("./Node.cjs");
/**
 * Represents an index access node.
 */
class IndexAccessNode extends Node_cjs_1.Node {
    /**
     * Initializes a new instance of the {@linkcode IndexAccessNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression of the index access operation.
     *
     * @param index
     * The index to access.
     */
    constructor(source, expression, index) {
        super(source);
        /**
         * @inheritdoc
         */
        this.Type = "IndexAccessNode" /* NodeKind.IndexAccessNode */;
        this.expression = expression;
        this.index = index;
    }
    /**
     * Gets the expression of the index access operation.
     */
    get Expression() {
        return this.expression;
    }
    /**
     * Gets the index to access.
     */
    get Index() {
        return this.index;
    }
    /**
     * @inheritdoc
     */
    get PathPart() {
        let source = this.Index.Source;
        switch (this.Index.Type) {
            case "NumericLiteralNode" /* NodeKind.NumericLiteralNode */:
            case "StringLiteralNode" /* NodeKind.StringLiteralNode */:
                let value;
                if (this.Index.Type === "NumericLiteralNode" /* NodeKind.NumericLiteralNode */) {
                    value = this.Index.Value;
                }
                else {
                    value = this.Index.Text;
                }
                return {
                    type: "IndexAccess" /* PathKind.IndexAccess */,
                    source,
                    value
                };
            case "InterpolationNode" /* NodeKind.InterpolationNode */:
                return this.index.PathPart;
            default:
                return {
                    type: "Unsupported" /* PathKind.Unsupported */,
                    isAccessor: true,
                    source
                };
        }
    }
    /**
     * @inheritdoc
     */
    get Path() {
        return [
            ...this.Expression.Path,
            this.PathPart
        ];
    }
    /**
     * @inheritdoc
     */
    get Root() {
        return this.Expression.Root;
    }
}
exports.IndexAccessNode = IndexAccessNode;
//# sourceMappingURL=IndexAccessNode.cjs.map