import { Node } from "./Node.cjs";
import { NodeKind } from "./NodeKind.cjs";
import { ParsedNode } from "./ParsedNode.cjs";
import { PathPartCandidate } from "./PathPartCandidate.cjs";
/**
 * Represents an index access node.
 */
export declare class IndexAccessNode<T> extends Node<T> {
    /**
     * @inheritdoc
     */
    readonly Type = NodeKind.IndexAccessNode;
    /**
     * The expression of the index access operation.
     */
    private expression;
    /**
     * The index to access.
     */
    private index;
    /**
     * Initializes a new instance of the {@linkcode IndexAccessNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression of the index access operation.
     *
     * @param index
     * The index to access.
     */
    constructor(source: T, expression: ParsedNode<T>, index: ParsedNode<T>);
    /**
     * Gets the expression of the index access operation.
     */
    get Expression(): ParsedNode<T>;
    /**
     * Gets the index to access.
     */
    get Index(): ParsedNode<T>;
    /**
     * @inheritdoc
     */
    get PathPart(): PathPartCandidate<T>;
    /**
     * @inheritdoc
     */
    get Path(): Array<PathPartCandidate<T>>;
    /**
     * @inheritdoc
     */
    get Root(): ParsedNode<T>;
}
