"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropertyAccessNode = void 0;
const Node_cjs_1 = require("./Node.cjs");
/**
 * Represents a property access.
 */
class PropertyAccessNode extends Node_cjs_1.Node {
    /**
     * Initializes a new instance of the {@linkcode PropertyAccessNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression of the property access operation.
     *
     * @param propertyName
     * The name of the property to access.
     */
    constructor(source, expression, propertyName) {
        super(source);
        /**
         * @inheritdoc
         */
        this.Type = "PropertyAccessNode" /* NodeKind.PropertyAccessNode */;
        this.expression = expression;
        this.propertyName = propertyName;
    }
    /**
     * @inheritdoc
     */
    get Expression() {
        return this.expression;
    }
    /**
     * Gets the name of the property to access.
     */
    get PropertyName() {
        return this.propertyName;
    }
    /**
     * @inheritdoc
     */
    get PathPart() {
        return {
            type: "PropertyAccess" /* PathKind.PropertyAccess */,
            source: this.Source,
            value: this.PropertyName
        };
    }
    /**
     * @inheritdoc
     */
    get Path() {
        return [
            ...this.Expression.Path,
            this.PathPart
        ];
    }
    /**
     * @inheritdoc
     */
    get Root() {
        return this.Expression.Root;
    }
}
exports.PropertyAccessNode = PropertyAccessNode;
//# sourceMappingURL=PropertyAccessNode.cjs.map