"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransformerBase = void 0;
const UnusedInterpolationError_cjs_1 = require("../Diagnostics/UnusedInterpolationError.cjs");
/**
 * Provides a basic implementation of a transformer.
 *
 * @template TNode
 * The type of the nodes to transform.
 *
 * @template TFeatures
 * The type of the features
 */
class TransformerBase {
    /**
     * Initializes a new instance of the {@linkcode TransformerBase TransformerBase<TNode, TFeatures>} class.
     *
     * @param features
     * A set of features for performing transformations.
     */
    constructor(features) {
        this.features = features;
    }
    /**
     * Gets the adapter for transforming nodes.
     */
    get Adapter() {
        if (!this.adapter) {
            this.adapter = this.InitializeAdapter();
        }
        return this.adapter;
    }
    /**
     * Gets a set of features for performing transformations.
     */
    get Features() {
        return this.features;
    }
    /**
     * Monitors the `nameof.interpolate` calls during the execution of the specified {@linkcode action}.
     *
     * @param action
     * The action to execute.
     *
     * @returns
     * The result of the action.
     */
    MonitorInterpolations(action) {
        var _a;
        let context = {
            interpolationCalls: []
        };
        let result = action(context);
        let remainingCall = (_a = context.interpolationCalls) === null || _a === void 0 ? void 0 : _a[0];
        if (remainingCall) {
            new UnusedInterpolationError_cjs_1.UnusedInterpolationError(this.Adapter, remainingCall, context).ReportAction();
        }
        return result;
    }
}
exports.TransformerBase = TransformerBase;
//# sourceMappingURL=TransformerBase.cjs.map